@@ -80,6 +80,7 @@
 
 #include "queue.h"
 #include "checkpolicy.h"
+#include "parse_util.h"
 
 extern char *optarg;
 extern int optind;
@@ -88,17 +89,8 @@ static policydb_t policydb;
 static sidtab_t sidtab;
 
 extern policydb_t *policydbp;
-extern queue_t id_queue;
-extern unsigned int policydb_errors;
-extern unsigned long policydb_lineno;
-extern char source_file[];
 extern int mlspol;
 
-extern FILE *yyin;
-extern void init_parser(int);
-extern int yyparse(void);
-extern void yyrestart(FILE *);
-
 static char *txtfile = "policy.conf";
 static char *binfile = "policy";
 
@@ -106,8 +98,9 @@ unsigned int policyvers = POLICYDB_VERSION_MAX;
 
 void usage(char *progname)
 {
-	printf("usage:  %s [-b] [-d] [-M] [-c policyvers (%d-%d)] [-o output_file] [input_file]\n",
-		progname, POLICYDB_VERSION_MIN, POLICYDB_VERSION_MAX);
+	printf
+	    ("usage:  %s [-b] [-d] [-M] [-c policyvers (%d-%d)] [-o output_file] [input_file]\n",
+	     progname, POLICYDB_VERSION_MIN, POLICYDB_VERSION_MAX);
 	exit(1);
 }
 
@@ -118,7 +111,9 @@ if (fgets(out,size,in)==NULL) {	\
 			exit(1);\
 }
 static int print_sid(sepol_security_id_t sid,
-		     context_struct_t * context __attribute__ ((unused)), void *data __attribute__ ((unused)))
+		     context_struct_t * context
+		     __attribute__ ((unused)), void *data
+		     __attribute__ ((unused)))
 {
 	sepol_security_context_t scontext;
 	size_t scontext_len;
@@ -146,7 +141,7 @@ static int find_perm(hashtab_key_t key, hashtab_datum_t datum, void *p)
 
 	perdatum = (perm_datum_t *) datum;
 
-	if (v->val == perdatum->value) {
+	if (v->val == perdatum->s.value) {
 		v->name = key;
 		return 1;
 	}
@@ -155,7 +150,7 @@ static int find_perm(hashtab_key_t key, hashtab_datum_t datum, void *p)
 }
 
 #ifdef EQUIVTYPES
-static int insert_type_rule(avtab_key_t *k, avtab_datum_t *d, 
+static int insert_type_rule(avtab_key_t * k, avtab_datum_t * d,
 			    struct avtab_node *type_rules)
 {
 	struct avtab_node *p, *c, *n;
@@ -168,10 +163,10 @@ static int insert_type_rule(avtab_key_t *k, avtab_datum_t *d,
 		 */
 		if (k->source_type < c->key.source_type)
 			break;
-		if (k->source_type == c->key.source_type && 
+		if (k->source_type == c->key.source_type &&
 		    k->target_type < c->key.target_type)
 			break;
-		if (k->source_type == c->key.source_type && 
+		if (k->source_type == c->key.source_type &&
 		    k->target_type == c->key.target_type &&
 		    k->target_class < c->key.target_class)
 			break;
@@ -191,7 +186,7 @@ static int insert_type_rule(avtab_key_t *k, avtab_datum_t *d,
 	return 0;
 }
 
-static int create_type_rules(avtab_key_t *k, avtab_datum_t *d, void *args)
+static int create_type_rules(avtab_key_t * k, avtab_datum_t * d, void *args)
 {
 	struct avtab_node *type_rules = args;
 
@@ -200,8 +195,10 @@ static int create_type_rules(avtab_key_t *k, avtab_datum_t *d, void *args)
 		 * Insert the rule into the lists for both 
 		 * the source type and the target type.
 		 */
-		if (insert_type_rule(k, d, &type_rules[k->source_type-1])) return -1;
-		if (insert_type_rule(k, d, &type_rules[k->target_type-1])) return -1;
+		if (insert_type_rule(k, d, &type_rules[k->source_type - 1]))
+			return -1;
+		if (insert_type_rule(k, d, &type_rules[k->target_type - 1]))
+			return -1;
 	}
 
 	return 0;
@@ -218,24 +215,24 @@ static void free_type_rules(struct avtab_node *l)
 	}
 }
 
-static int identify_equiv_types(void) 
+static int identify_equiv_types(void)
 {
-        struct avtab_node *type_rules, *l1, *l2;
+	struct avtab_node *type_rules, *l1, *l2;
 	int i, j;
 
 	/*
 	 * Create a list of access vector rules for each type
 	 * from the access vector table.
 	 */
-	type_rules = malloc(sizeof(struct avtab_node)*policydb.p_types.nprim);
+	type_rules = malloc(sizeof(struct avtab_node) * policydb.p_types.nprim);
 	if (!type_rules) {
 		fprintf(stderr, "out of memory\n");
 		exit(1);
 	}
-	memset(type_rules, 0, sizeof(struct avtab_node)*policydb.p_types.nprim);
+	memset(type_rules, 0,
+	       sizeof(struct avtab_node) * policydb.p_types.nprim);
 	if (avtab_map(&policydb.te_avtab, create_type_rules, type_rules))
 		exit(1);
-	
 
 	/*
 	 * Compare the type lists and identify equivalent types.
@@ -244,27 +241,29 @@ static int identify_equiv_types(void)
 		if (!type_rules[i].next)
 			continue;
 		for (j = i + 1; j < policydb.p_types.nprim; j++) {
-			for (l1 = type_rules[i].next, l2 = type_rules[j].next; l1 && l2;
-			     l1 = l1->next, l2 = l2->next) {
-				if (l2->key.source_type == (j+1)) {
-					if (l1->key.source_type != (i+1))
+			for (l1 = type_rules[i].next, l2 = type_rules[j].next;
+			     l1 && l2; l1 = l1->next, l2 = l2->next) {
+				if (l2->key.source_type == (j + 1)) {
+					if (l1->key.source_type != (i + 1))
 						break;
 				} else {
-					if (l1->key.source_type != l2->key.source_type)
+					if (l1->key.source_type !=
+					    l2->key.source_type)
 						break;
 				}
-				if (l2->key.target_type == (j+1)) {
-					if (l1->key.target_type != (i+1))
+				if (l2->key.target_type == (j + 1)) {
+					if (l1->key.target_type != (i + 1))
 						break;
 				} else {
-					if (l1->key.target_type != l2->key.target_type)
+					if (l1->key.target_type !=
+					    l2->key.target_type)
 						break;
 				}
-				if (l1->key.target_class != l2->key.target_class || 
-				    l1->datum.allowed != l2->datum.allowed)
+				if (l1->key.target_class != l2->key.target_class
+				    || l1->datum.allowed != l2->datum.allowed)
 					break;
 			}
-			if (l1 || l2) 
+			if (l1 || l2)
 				continue;
 			free_type_rules(type_rules[j].next);
 			type_rules[j].next = NULL;
@@ -272,37 +271,37 @@ static int identify_equiv_types(void)
 			       policydb.p_type_val_to_name[i],
 			       policydb.p_type_val_to_name[j]);
 		}
-		free_type_rules(type_rules[i].next);		
+		free_type_rules(type_rules[i].next);
 		type_rules[i].next = NULL;
 	}
 
-	free(type_rules);	
+	free(type_rules);
 	return 0;
 }
-#endif 
+#endif
 
 extern char *av_to_string(uint32_t tclass, sepol_access_vector_t av);
 
-
 int display_bools()
 {
 	int i;
 
 	for (i = 0; i < policydbp->p_bools.nprim; i++) {
 		printf("%s : %d\n", policydbp->p_bool_val_to_name[i],
-			policydbp->bool_val_to_struct[i]->state);
+		       policydbp->bool_val_to_struct[i]->state);
 	}
 	return 0;
 }
 
-void display_expr(cond_expr_t *exp)
+void display_expr(cond_expr_t * exp)
 {
 
 	cond_expr_t *cur;
 	for (cur = exp; cur != NULL; cur = cur->next) {
 		switch (cur->expr_type) {
 		case COND_BOOL:
-			printf("%s ", policydbp->p_bool_val_to_name[cur->bool - 1]);
+			printf("%s ",
+			       policydbp->p_bool_val_to_name[cur->bool - 1]);
 			break;
 		case COND_NOT:
 			printf("! ");
@@ -360,7 +359,9 @@ static int check_level(hashtab_key_t key, hashtab_datum_t datum, void *arg)
 	level_datum_t *levdatum = (level_datum_t *) datum;
 
 	if (!levdatum->isalias && !levdatum->defined) {
-		fprintf(stderr, "Error:  sensitivity %s was not used in a level definition!\n", key);
+		fprintf(stderr,
+			"Error:  sensitivity %s was not used in a level definition!\n",
+			key);
 		return -1;
 	}
 	return 0;
@@ -389,7 +390,6 @@ int main(int argc, char **argv)
 	int show_version = 0;
 	struct policy_file pf;
 
-
 	while ((ch = getopt(argc, argv, "o:dbMVc:")) != EOF) {
 		switch (ch) {
 		case 'o':
@@ -408,30 +408,36 @@ int main(int argc, char **argv)
 		case 'M':
 			mlspol = 1;
 			break;
-		case 'c': {
-			long int n = strtol(optarg, NULL, 10);
-			if (errno) {
-				fprintf(stderr, "Invalid policyvers specified: %s\n", optarg);
-				usage(argv[0]);
-				exit(1);
+		case 'c':{
+				long int n = strtol(optarg, NULL, 10);
+				if (errno) {
+					fprintf(stderr,
+						"Invalid policyvers specified: %s\n",
+						optarg);
+					usage(argv[0]);
+					exit(1);
+				}
+				if (n < POLICYDB_VERSION_MIN
+				    || n > POLICYDB_VERSION_MAX) {
+					fprintf(stderr,
+						"policyvers value %ld not in range %d-%d\n",
+						n, POLICYDB_VERSION_MIN,
+						POLICYDB_VERSION_MAX);
+					usage(argv[0]);
+					exit(1);
+				}
+				if (policyvers != n)
+					policyvers = n;
+				break;
 			}
-			if (n < POLICYDB_VERSION_MIN || n > POLICYDB_VERSION_MAX) {
-				fprintf(stderr, "policyvers value %ld not in range %d-%d\n",
-					n, POLICYDB_VERSION_MIN, POLICYDB_VERSION_MAX);
-				usage(argv[0]);
-				exit(1);
-			}
-			if (policyvers != n)
-				policyvers = n;
-			break;
-		}
 		default:
 			usage(argv[0]);
 		}
 	}
 
 	if (show_version) {
-		printf("%d (compatibility range %d-%d)\n", policyvers, POLICYDB_VERSION_MAX, POLICYDB_VERSION_MIN);
+		printf("%d (compatibility range %d-%d)\n", policyvers,
+		       POLICYDB_VERSION_MAX, POLICYDB_VERSION_MIN);
 		exit(0);
 	}
 
@@ -440,8 +446,7 @@ int main(int argc, char **argv)
 		if (optind != argc)
 			usage(argv[0]);
 	}
-	printf("%s:  loading policy configuration from %s\n", argv[0],
-	       file);
+	printf("%s:  loading policy configuration from %s\n", argv[0], file);
 
 	/* Set policydb and sidtab used by libsepol service functions
 	   to my structures, so that I can directly populate and
@@ -461,7 +466,9 @@ int main(int argc, char **argv)
 				file, strerror(errno));
 			exit(1);
 		}
-		map = mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
+		map =
+		    mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE,
+			 fd, 0);
 		if (map == MAP_FAILED) {
 			fprintf(stderr, "Can't map '%s':  %s\n",
 				file, strerror(errno));
@@ -471,12 +478,15 @@ int main(int argc, char **argv)
 		pf.data = map;
 		pf.len = sb.st_size;
 		if (policydb_init(&policydb)) {
-			fprintf(stderr, "%s:  policydb_init:  Out of memory!\n", argv[0]);
+			fprintf(stderr, "%s:  policydb_init:  Out of memory!\n",
+				argv[0]);
 			exit(1);
 		}
 		ret = policydb_read(&policydb, &pf, 1);
 		if (ret) {
-			fprintf(stderr, "%s:  error(s) encountered while parsing configuration\n", argv[0]);
+			fprintf(stderr,
+				"%s:  error(s) encountered while parsing configuration\n",
+				argv[0]);
 			exit(1);
 		}
 		policydbp = &policydb;
@@ -484,26 +494,19 @@ int main(int argc, char **argv)
 		/* Check Policy Consistency */
 		if (policydbp->mls) {
 			if (!mlspol) {
-				fprintf(stderr,"%s:  MLS policy, but non-MLS"
-				        " is specified\n", argv[0]);
+				fprintf(stderr, "%s:  MLS policy, but non-MLS"
+					" is specified\n", argv[0]);
 				exit(1);
 			}
 		} else {
 			if (mlspol) {
-				fprintf(stderr,"%s:  non-MLS policy, but MLS"
-				        " is specified\n", argv[0]);
+				fprintf(stderr, "%s:  non-MLS policy, but MLS"
+					" is specified\n", argv[0]);
 				exit(1);
 			}
 		}
 	} else {
-                policydb_t parse_policy;
-
-                yyin = fopen(file, "r");
-		if (!yyin) {
-			fprintf(stderr, "%s:  unable to open %s\n", argv[0], 
-				file);
-			exit(1);
-		}
+		policydb_t parse_policy;
 
 		if (policydb_init(&parse_policy))
 			exit(1);
@@ -513,28 +516,9 @@ int main(int argc, char **argv)
 		/* Let sepol know if we are dealing with MLS support */
 		parse_policy.mls = mlspol;
 
-		id_queue = queue_create();
-		if (!id_queue) {
-			fprintf(stderr, "%s:  out of memory\n", argv[0]);
-			exit(1);
-		}
 		policydbp = &parse_policy;
-                init_parser(1);
-		if (yyparse() || policydb_errors) {
-			fprintf(stderr, "%s:  error(s) encountered while parsing configuration\n", argv[0]);
-			exit(1);
-		}
-		rewind(yyin);
-                init_parser(2);
-		source_file[0] = '\0';
-		yyrestart(yyin);
-		if (yyparse() || policydb_errors) {
-			fprintf(stderr, "%s:  error(s) encountered while parsing configuration\n", argv[0]);
-			exit(1);
-		}
-		queue_destroy(id_queue);
 
-		if (policydb_errors) 
+		if (read_source_policy(policydbp, file, "checkpolicy") < 0)
 			exit(1);
 
 		if (hashtab_map(policydbp->p_levels.table, check_level, NULL))
@@ -546,18 +530,17 @@ int main(int argc, char **argv)
 		}
 
 		/* Linking takes care of optional avrule blocks */
-        	if (link_modules(NULL, &parse_policy, NULL, 0, 0)) {
+		if (link_modules(NULL, &parse_policy, NULL, 0, 0)) {
 			fprintf(stderr, "Error while resolving optionals\n");
 			exit(1);
 		}
 
 		if (expand_module(NULL, &parse_policy, &policydb, 0, 1)) {
-                        fprintf(stderr, "Error while expanding policy\n");
+			fprintf(stderr, "Error while expanding policy\n");
 			exit(1);
-                }
+		}
 		policydb_destroy(&parse_policy);
 		policydbp = &policydb;
-		fclose(yyin);
 	}
 
 	if (policydb_load_isids(&policydb, &sidtab))
@@ -566,8 +549,9 @@ int main(int argc, char **argv)
 	printf("%s:  policy configuration loaded\n", argv[0]);
 
 	if (outfile) {
-		printf("%s:  writing binary representation (version %d) to %s\n",
-		       argv[0], policyvers, outfile);
+		printf
+		    ("%s:  writing binary representation (version %d) to %s\n",
+		     argv[0], policyvers, outfile);
 		outfp = fopen(outfile, "w");
 		if (!outfp) {
 			perror(outfile);
@@ -634,39 +618,51 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			if (isdigit(ans[0])) {
 				tclass = atoi(ans);
-				if (!tclass || tclass > policydb.p_classes.nprim) {
+				if (!tclass
+				    || tclass > policydb.p_classes.nprim) {
 					printf("\nNo such class.\n");
 					break;
 				}
-				cladatum = policydb.class_val_to_struct[tclass - 1];
+				cladatum =
+				    policydb.class_val_to_struct[tclass - 1];
 			} else {
 				ans[strlen(ans) - 1] = 0;
-				cladatum = (class_datum_t *) hashtab_search(policydb.p_classes.table,
-								    ans);
+				cladatum =
+				    (class_datum_t *) hashtab_search(policydb.
+								     p_classes.
+								     table,
+								     ans);
 				if (!cladatum) {
 					printf("\nNo such class\n");
 					break;
 				}
-				tclass = cladatum->value;
+				tclass = cladatum->s.value;
 			}
 
 			if (!cladatum->comdatum && !cladatum->permissions.nprim) {
-				printf("\nNo access vector definition for that class\n");
+				printf
+				    ("\nNo access vector definition for that class\n");
 				break;
 			}
-			ret = sepol_compute_av(ssid, tsid, tclass, 0,
-						  &avd);
+			ret = sepol_compute_av(ssid, tsid, tclass, 0, &avd);
 			switch (ret) {
 			case 0:
 				printf("\nallowed {");
 				for (i = 1; i <= sizeof(avd.allowed) * 8; i++) {
 					if (avd.allowed & (1 << (i - 1))) {
 						v.val = i;
-						ret = hashtab_map(cladatum->permissions.table,
-								   find_perm, &v);
+						ret =
+						    hashtab_map(cladatum->
+								permissions.
+								table,
+								find_perm, &v);
 						if (!ret && cladatum->comdatum) {
-							ret = hashtab_map(cladatum->comdatum->permissions.table,
-									 find_perm, &v);
+							ret =
+							    hashtab_map
+							    (cladatum->
+							     comdatum->
+							     permissions.table,
+							     find_perm, &v);
 						}
 						if (ret)
 							printf(" %s", v.name);
@@ -686,7 +682,7 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			ssid = atoi(ans);
 			ret = sepol_sid_to_context(ssid,
-					       &scontext, &scontext_len);
+						   &scontext, &scontext_len);
 			switch (ret) {
 			case 0:
 				printf("\nscontext %s\n", scontext);
@@ -707,8 +703,7 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			scontext_len = strlen(ans);
 			ans[scontext_len - 1] = 0;
-			ret = sepol_context_to_sid(ans, scontext_len,
-						      &ssid);
+			ret = sepol_context_to_sid(ans, scontext_len, &ssid);
 			switch (ret) {
 			case 0:
 				printf("\nsid %d\n", ssid);
@@ -739,27 +734,35 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			if (isdigit(ans[0])) {
 				tclass = atoi(ans);
-				if (!tclass || tclass > policydb.p_classes.nprim) {
+				if (!tclass
+				    || tclass > policydb.p_classes.nprim) {
 					printf("\nNo such class.\n");
 					break;
 				}
 			} else {
 				ans[strlen(ans) - 1] = 0;
-				cladatum = (class_datum_t *) hashtab_search(policydb.p_classes.table,
-								    ans);
+				cladatum =
+				    (class_datum_t *) hashtab_search(policydb.
+								     p_classes.
+								     table,
+								     ans);
 				if (!cladatum) {
 					printf("\nNo such class\n");
 					break;
 				}
-				tclass = cladatum->value;
+				tclass = cladatum->s.value;
 			}
 
 			if (ch == '3')
-				ret = sepol_transition_sid(ssid, tsid, tclass, &ssid);
+				ret =
+				    sepol_transition_sid(ssid, tsid, tclass,
+							 &ssid);
 			else if (ch == '4')
-				ret = sepol_member_sid(ssid, tsid, tclass, &ssid);
-			else 
-				ret = sepol_change_sid(ssid, tsid, tclass, &ssid);
+				ret =
+				    sepol_member_sid(ssid, tsid, tclass, &ssid);
+			else
+				ret =
+				    sepol_change_sid(ssid, tsid, tclass, &ssid);
 			switch (ret) {
 			case 0:
 				printf("\nsid %d\n", ssid);
@@ -782,7 +785,8 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			pathlen = strlen(ans);
 			ans[pathlen - 1] = 0;
-			printf("%s:  loading policy configuration from %s\n", argv[0], ans);
+			printf("%s:  loading policy configuration from %s\n",
+			       argv[0], ans);
 			fd = open(ans, O_RDONLY);
 			if (fd < 0) {
 				fprintf(stderr, "Can't open '%s':  %s\n",
@@ -794,13 +798,15 @@ int main(int argc, char **argv)
 					ans, strerror(errno));
 				break;
 			}
-			map = mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
+			map =
+			    mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE,
+				 MAP_PRIVATE, fd, 0);
 			if (map == MAP_FAILED) {
 				fprintf(stderr, "Can't map '%s':  %s\n",
 					ans, strerror(errno));
 				break;
 			}
-			ret = sepol_load_policy(map,sb.st_size);
+			ret = sepol_load_policy(map, sb.st_size);
 			switch (ret) {
 			case 0:
 				printf("\nsuccess\n");
@@ -820,8 +826,7 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
 			sepol_fs_sid(ans, &ssid, &tsid);
-			printf("fs_sid %d default_file_sid %d\n",
-			       ssid, tsid);
+			printf("fs_sid %d default_file_sid %d\n", ssid, tsid);
 			break;
 		case '9':
 			printf("protocol?  ");
@@ -846,48 +851,47 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
 			sepol_netif_sid(ans, &ssid, &tsid);
-			printf("if_sid %d default_msg_sid %d\n",
-			       ssid, tsid);
+			printf("if_sid %d default_msg_sid %d\n", ssid, tsid);
 			break;
-		case 'b': {
-			char *p;
-			int family, len;
-			struct in_addr addr4;
-			struct in6_addr addr6;
-			
-			printf("protocol family? ");
-			FGETS(ans, sizeof(ans), stdin);
-			ans[strlen(ans) - 1] = 0;
-			if (!strcasecmp(ans, "ipv4"))
-				family = AF_INET;
-			else if (!strcasecmp(ans, "ipv6"))
-				family = AF_INET6;
-			else {
-				printf("unknown protocol family\n");
-				break;
-			}
-			
-			printf("node address?  ");
-			FGETS(ans, sizeof(ans), stdin);
-			ans[strlen(ans) - 1] = 0;
-			
-			if (family == AF_INET) {
-				p = (char *)&addr4;
-				len = sizeof(addr4);
-			} else {
-				p = (char *)&addr6;
-				len = sizeof(addr6);
-			}
-			
-			if (inet_pton(family, ans, p) < 1) {
-				printf("error parsing address\n");
-				break;
-			}
+		case 'b':{
+				char *p;
+				int family, len;
+				struct in_addr addr4;
+				struct in6_addr addr6;
 
-			sepol_node_sid(family, p, len, &ssid);
-			printf("sid %d\n", ssid);
-			break;
-		}	
+				printf("protocol family? ");
+				FGETS(ans, sizeof(ans), stdin);
+				ans[strlen(ans) - 1] = 0;
+				if (!strcasecmp(ans, "ipv4"))
+					family = AF_INET;
+				else if (!strcasecmp(ans, "ipv6"))
+					family = AF_INET6;
+				else {
+					printf("unknown protocol family\n");
+					break;
+				}
+
+				printf("node address?  ");
+				FGETS(ans, sizeof(ans), stdin);
+				ans[strlen(ans) - 1] = 0;
+
+				if (family == AF_INET) {
+					p = (char *)&addr4;
+					len = sizeof(addr4);
+				} else {
+					p = (char *)&addr6;
+					len = sizeof(addr6);
+				}
+
+				if (inet_pton(family, ans, p) < 1) {
+					printf("error parsing address\n");
+					break;
+				}
+
+				sepol_node_sid(family, p, len, &ssid);
+				printf("sid %d\n", ssid);
+				break;
+			}
 		case 'c':
 			printf("fstype?  ");
 			FGETS(ans, sizeof(ans), stdin);
@@ -925,19 +929,23 @@ int main(int argc, char **argv)
 			FGETS(ans, sizeof(ans), stdin);
 			if (isdigit(ans[0])) {
 				tclass = atoi(ans);
-				if (!tclass || tclass > policydb.p_classes.nprim) {
+				if (!tclass
+				    || tclass > policydb.p_classes.nprim) {
 					printf("\nNo such class.\n");
 					break;
 				}
 			} else {
 				ans[strlen(ans) - 1] = 0;
-				cladatum = (class_datum_t *) hashtab_search(policydb.p_classes.table,
-								    ans);
+				cladatum =
+				    (class_datum_t *) hashtab_search(policydb.
+								     p_classes.
+								     table,
+								     ans);
 				if (!cladatum) {
 					printf("\nNo such class\n");
 					break;
 				}
-				tclass = cladatum->value;
+				tclass = cladatum->s.value;
 			}
 			sepol_genfs_sid(fstype, path, tclass, &ssid);
 			printf("sid %d\n", ssid);
@@ -957,10 +965,10 @@ int main(int argc, char **argv)
 			ret = sepol_get_user_sids(ssid, ans, &sids, &nel);
 			switch (ret) {
 			case 0:
-			        if (!nel)
-				        printf("\nnone\n");
+				if (!nel)
+					printf("\nnone\n");
 				for (i = 0; i < nel; i++)
-					print_sid(sids[i],NULL,NULL);
+					print_sid(sids[i], NULL, NULL);
 				free(sids);
 				break;
 			case -ENOMEM:
@@ -984,7 +992,7 @@ int main(int argc, char **argv)
 			printf("name? ");
 			FGETS(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
-			
+
 			name = malloc((strlen(ans) + 1) * sizeof(char));
 			if (name == NULL) {
 				fprintf(stderr, "couldn't malloc string.\n");
@@ -992,7 +1000,6 @@ int main(int argc, char **argv)
 			}
 			strcpy(name, ans);
 
-
 			printf("state? ");
 			FGETS(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
@@ -1024,4 +1031,3 @@ int main(int argc, char **argv)
 }
 
 /* FLASK */
-
