@@ -6,7 +6,7 @@
  *  	it under the terms of the GNU General Public License as published by
  *	the Free Software Foundation, version 2.
  */
- 
+
 /* 
  * displaypol.c
  *
@@ -22,6 +22,7 @@
 #include <sepol/policydb/services.h>
 #include <sepol/policydb/conditional.h>
 #include <sepol/policydb/expand.h>
+#include <sepol/policydb/util.h>
 #include <getopt.h>
 #include <assert.h>
 #include <unistd.h>
@@ -41,7 +42,8 @@ void usage(char *progname)
 	exit(1);
 }
 
-int render_access_mask(uint32_t mask, avtab_key_t *key, policydb_t *p, FILE *fp)
+int render_access_mask(uint32_t mask, avtab_key_t * key, policydb_t * p,
+		       FILE * fp)
 {
 	char *perm;
 	fprintf(fp, "{");
@@ -52,26 +54,27 @@ int render_access_mask(uint32_t mask, avtab_key_t *key, policydb_t *p, FILE *fp)
 	return 0;
 }
 
-int render_type(uint32_t type, policydb_t *p, FILE *fp)
+int render_type(uint32_t type, policydb_t * p, FILE * fp)
 {
 	fprintf(fp, "%s", p->p_type_val_to_name[type - 1]);
 	return 0;
 }
 
-int render_key(avtab_key_t *key, policydb_t *p, FILE *fp)
+int render_key(avtab_key_t * key, policydb_t * p, FILE * fp)
 {
 	char *stype, *ttype, *tclass;
 	stype = p->p_type_val_to_name[key->source_type - 1];
 	ttype = p->p_type_val_to_name[key->target_type - 1];
 	tclass = p->p_class_val_to_name[key->target_class - 1];
-	if (stype && ttype) 
+	if (stype && ttype)
 		fprintf(fp, "%s %s : %s ", stype, ttype, tclass);
 	else if (stype)
 		fprintf(fp, "%s %u : %s ", stype, key->target_type, tclass);
 	else if (ttype)
 		fprintf(fp, "%u %s : %s ", key->source_type, ttype, tclass);
 	else
-		fprintf(fp, "%u %u : %s ", key->source_type, key->target_type, tclass);
+		fprintf(fp, "%u %u : %s ", key->source_type, key->target_type,
+			tclass);
 	return 0;
 }
 
@@ -81,79 +84,83 @@ int render_key(avtab_key_t *key, policydb_t *p, FILE *fp)
 #define RENDER_DISABLED		0x0004
 #define RENDER_CONDITIONAL	(RENDER_ENABLED|RENDER_DISABLED)
 
-int render_av_rule(avtab_key_t *key, avtab_datum_t *datum, uint32_t what, policydb_t *p, FILE *fp)
+int render_av_rule(avtab_key_t * key, avtab_datum_t * datum, uint32_t what,
+		   policydb_t * p, FILE * fp)
 {
-	if(!(what & RENDER_UNCONDITIONAL)) {
-		if(what != RENDER_CONDITIONAL &&
-		   (((what & RENDER_ENABLED) && !(key->specified & AVTAB_ENABLED)) ||
-		   ((what & RENDER_DISABLED) && (key->specified & AVTAB_ENABLED)))) {
-		   	return 0; /* doesn't match selection criteria */
-		} 
+	if (!(what & RENDER_UNCONDITIONAL)) {
+		if (what != RENDER_CONDITIONAL && (((what & RENDER_ENABLED)
+						    && !(key->
+							 specified &
+							 AVTAB_ENABLED))
+						   || ((what & RENDER_DISABLED)
+						       && (key->
+							   specified &
+							   AVTAB_ENABLED)))) {
+			return 0;	/* doesn't match selection criteria */
+		}
 	}
 
-	if(!(what & RENDER_UNCONDITIONAL)) {
-		if(key->specified & AVTAB_ENABLED) 
+	if (!(what & RENDER_UNCONDITIONAL)) {
+		if (key->specified & AVTAB_ENABLED)
 			fprintf(fp, "[enabled] ");
-		else if(!(key->specified & AVTAB_ENABLED))
+		else if (!(key->specified & AVTAB_ENABLED))
 			fprintf(fp, "[disabled] ");
-	} 
+	}
 
-	if( key->specified & AVTAB_AV) {
-		if(key->specified & AVTAB_ALLOWED) {
-			fprintf(fp, "allow ");			
+	if (key->specified & AVTAB_AV) {
+		if (key->specified & AVTAB_ALLOWED) {
+			fprintf(fp, "allow ");
 			render_key(key, p, fp);
-			render_access_mask(datum->data,key, p, fp);
+			render_access_mask(datum->data, key, p, fp);
 			fprintf(fp, ";\n");
 		}
-		if(key->specified & AVTAB_AUDITALLOW) {
+		if (key->specified & AVTAB_AUDITALLOW) {
 			fprintf(fp, "auditallow ");
 			render_key(key, p, fp);
-			render_access_mask(datum->data,key, p, fp);
+			render_access_mask(datum->data, key, p, fp);
 			fprintf(fp, ";\n");
 		}
-		if(key->specified & AVTAB_AUDITDENY) {
+		if (key->specified & AVTAB_AUDITDENY) {
 			fprintf(fp, "dontaudit ");
 			render_key(key, p, fp);
 			/* We inverse the mask for dontaudit since the mask is internally stored
 			 * as a auditdeny mask */
-			render_access_mask(~datum->data,key, p, fp);
+			render_access_mask(~datum->data, key, p, fp);
 			fprintf(fp, ";\n");
 		}
-	}
-	else if( key->specified & AVTAB_TYPE){
-		if(key->specified & AVTAB_TRANSITION) {
+	} else if (key->specified & AVTAB_TYPE) {
+		if (key->specified & AVTAB_TRANSITION) {
 			fprintf(fp, "type_transition ");
 			render_key(key, p, fp);
 			render_type(datum->data, p, fp);
 			fprintf(fp, ";\n");
 		}
-		if(key->specified & AVTAB_MEMBER) {
+		if (key->specified & AVTAB_MEMBER) {
 			fprintf(fp, "type_member ");
 			render_key(key, p, fp);
 			render_type(datum->data, p, fp);
 			fprintf(fp, ";\n");
 		}
-		if(key->specified & AVTAB_CHANGE) {
+		if (key->specified & AVTAB_CHANGE) {
 			fprintf(fp, "type_change ");
 			render_key(key, p, fp);
 			render_type(datum->data, p, fp);
 			fprintf(fp, ";\n");
 		}
-	}
-	else {
+	} else {
 		fprintf(fp, "     ERROR: no valid rule type specified\n");
 		return -1;
 	}
 	return 0;
 }
 
-int display_avtab(avtab_t *a, uint32_t what, policydb_t *p, FILE *fp)
+int display_avtab(avtab_t * a, uint32_t what, policydb_t * p, FILE * fp)
 {
 	int i;
 	avtab_ptr_t cur;
 	avtab_t expa;
 
-	if (avtab_init(&expa)) 
+	if (avtab_init(&expa))
 		goto oom;
 	if (expand_avtab(p, a, &expa)) {
 		avtab_destroy(&expa);
@@ -169,12 +176,12 @@ int display_avtab(avtab_t *a, uint32_t what, policydb_t *p, FILE *fp)
 	avtab_destroy(&expa);
 	fprintf(fp, "\n");
 	return 0;
-oom:
+      oom:
 	fprintf(stderr, "out of memory\n");
 	return 1;
 }
 
-int display_bools(policydb_t *p, FILE *fp)
+int display_bools(policydb_t * p, FILE * fp)
 {
 	int i;
 
@@ -185,14 +192,15 @@ int display_bools(policydb_t *p, FILE *fp)
 	return 0;
 }
 
-void display_expr(policydb_t *p, cond_expr_t *exp, FILE *fp)
+void display_expr(policydb_t * p, cond_expr_t * exp, FILE * fp)
 {
 
 	cond_expr_t *cur;
 	for (cur = exp; cur != NULL; cur = cur->next) {
 		switch (cur->expr_type) {
 		case COND_BOOL:
-			fprintf(fp, "%s ", p->p_bool_val_to_name[cur->bool - 1]);
+			fprintf(fp, "%s ",
+				p->p_bool_val_to_name[cur->bool - 1]);
 			break;
 		case COND_NOT:
 			fprintf(fp, "! ");
@@ -219,13 +227,12 @@ void display_expr(policydb_t *p, cond_expr_t *exp, FILE *fp)
 	}
 }
 
-int display_cond_expressions(policydb_t *p, FILE *fp)
+int display_cond_expressions(policydb_t * p, FILE * fp)
 {
 	cond_node_t *cur;
 	cond_av_list_t *av_cur, *expl = NULL;
 	avtab_t expa;
 
-
 	for (cur = p->cond_list; cur != NULL; cur = cur->next) {
 		fprintf(fp, "expression: ");
 		display_expr(p, cur->expr, fp);
@@ -261,12 +268,12 @@ int display_cond_expressions(policydb_t *p, FILE *fp)
 	}
 	return 0;
 
-oom:
+      oom:
 	fprintf(stderr, "out of memory\n");
 	return 1;
 }
 
-int change_bool(char *name, int state, policydb_t *p, FILE *fp)
+int change_bool(char *name, int state, policydb_t * p, FILE * fp)
 {
 	cond_bool_datum_t *bool;
 
@@ -280,7 +287,8 @@ int change_bool(char *name, int state, policydb_t *p, FILE *fp)
 	return 0;
 }
 
-int menu() {
+int menu()
+{
 	printf("\nSelect a command:\n");
 	printf("1)  display unconditional AVTAB\n");
 	printf("2)  display conditional AVTAB (entirely)\n");
@@ -296,7 +304,6 @@ int menu() {
 	return 0;
 }
 
-
 int main(int argc, char **argv)
 {
 	FILE *out_fp = stdout;
@@ -308,8 +315,7 @@ int main(int argc, char **argv)
 	int state;
 	struct policy_file pf;
 
-
-	if(argc != 2) 
+	if (argc != 2)
 		usage(argv[0]);
 
 	fd = open(argv[1], O_RDONLY);
@@ -323,13 +329,14 @@ int main(int argc, char **argv)
 			argv[1], strerror(errno));
 		exit(1);
 	}
-	map = mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
+	map =
+	    mmap(NULL, sb.st_size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
 	if (map == MAP_FAILED) {
 		fprintf(stderr, "Can't map '%s':  %s\n",
 			argv[1], strerror(errno));
 		exit(1);
 	}
-	
+
 	/* read the binary policy */
 	fprintf(out_fp, "Reading policy...\n");
 	pf.type = PF_USE_MEMORY;
@@ -341,30 +348,36 @@ int main(int argc, char **argv)
 	}
 	ret = policydb_read(&policydb, &pf, 1);
 	if (ret) {
-		fprintf(stderr, "%s:  error(s) encountered while parsing configuration\n", argv[0]);
+		fprintf(stderr,
+			"%s:  error(s) encountered while parsing configuration\n",
+			argv[0]);
 		exit(1);
 	}
 
 	fprintf(stdout, "binary policy file loaded\n\n");
 	close(fd);
-	
+
 	menu();
-	for(;;) {
+	for (;;) {
 		printf("\nCommand (\'m\' for menu):  ");
-		fgets(ans, sizeof(ans), stdin);	
-		switch(ans[0]) {
-			
+		fgets(ans, sizeof(ans), stdin);
+		switch (ans[0]) {
+
 		case '1':
-			display_avtab(&policydb.te_avtab, RENDER_UNCONDITIONAL, &policydb, out_fp);
+			display_avtab(&policydb.te_avtab, RENDER_UNCONDITIONAL,
+				      &policydb, out_fp);
 			break;
 		case '2':
-			display_avtab(&policydb.te_cond_avtab, RENDER_CONDITIONAL, &policydb, out_fp);
+			display_avtab(&policydb.te_cond_avtab,
+				      RENDER_CONDITIONAL, &policydb, out_fp);
 			break;
 		case '3':
-			display_avtab(&policydb.te_cond_avtab, RENDER_ENABLED, &policydb, out_fp);
+			display_avtab(&policydb.te_cond_avtab, RENDER_ENABLED,
+				      &policydb, out_fp);
 			break;
 		case '4':
-			display_avtab(&policydb.te_cond_avtab, RENDER_DISABLED, &policydb, out_fp);
+			display_avtab(&policydb.te_cond_avtab, RENDER_DISABLED,
+				      &policydb, out_fp);
 			break;
 		case '5':
 			display_bools(&policydb, out_fp);
@@ -376,7 +389,7 @@ int main(int argc, char **argv)
 			printf("name? ");
 			fgets(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
-			
+
 			name = malloc((strlen(ans) + 1) * sizeof(char));
 			if (name == NULL) {
 				fprintf(stderr, "couldn't malloc string.\n");
@@ -384,7 +397,6 @@ int main(int argc, char **argv)
 			}
 			strcpy(name, ans);
 
-
 			printf("state? ");
 			fgets(ans, sizeof(ans), stdin);
 			ans[strlen(ans) - 1] = 0;
@@ -398,16 +410,18 @@ int main(int argc, char **argv)
 			free(name);
 			break;
 		case 'f':
-			printf("\nFilename for output (<CR> for screen output): ");
-			fgets(OutfileName, sizeof(OutfileName), stdin);	
-			OutfileName[strlen(OutfileName)-1] = '\0'; /* fix_string (remove LF) */
-			if (strlen(OutfileName) == 0) 
+			printf
+			    ("\nFilename for output (<CR> for screen output): ");
+			fgets(OutfileName, sizeof(OutfileName), stdin);
+			OutfileName[strlen(OutfileName) - 1] = '\0';	/* fix_string (remove LF) */
+			if (strlen(OutfileName) == 0)
 				out_fp = stdout;
 			else if ((out_fp = fopen(OutfileName, "w")) == NULL) {
-				fprintf (stderr, "Cannot open output file %s\n", OutfileName);
+				fprintf(stderr, "Cannot open output file %s\n",
+					OutfileName);
 				out_fp = stdout;
 			}
-			if (out_fp != stdout) 
+			if (out_fp != stdout)
 				printf("\nOutput to file: %s\n", OutfileName);
 			break;
 		case 'q':
@@ -421,10 +435,9 @@ int main(int argc, char **argv)
 			printf("\nInvalid choice\n");
 			menu();
 			break;
-		
+
 		}
 	}
 }
 
 /* FLASK */
-
